Learn R Programming

hystar (version 1.0.0)

hystar-package: hystar: Fit the Hysteretic Threshold Autoregressive Model

Description

Estimate parameters of the hysteretic threshold autoregressive (HysTAR) model, using conditional least squares. In addition, you can generate time series data from the HysTAR model. For details, see Li, Guan, Li and Yu (2015) tools:::Rd_expr_doi("10.1093/biomet/asv017").

Arguments

Author

Maintainer: Daan de Jong daandejong94@gmail.com (ORCID) [copyright holder]

Other contributors:

  • European Research Council [funder]

See Also